@@ -125,6 +125,7 @@ def connect(
     tcp_keepalive=True,
     application_name=None,
     replication=None,
+    startup_params=None,
 ):
     return Connection(
         user,
@@ -139,6 +140,7 @@ def connect(
         tcp_keepalive=tcp_keepalive,
         application_name=application_name,
         replication=replication,
+        startup_params=startup_params,
     )
 
 
