@@ -261,10 +261,9 @@ def test_tpc_prepare(con):
     con.tpc_rollback(xid)
 
 
-# An empty query should raise a ProgrammingError
 def test_empty_query(cursor):
-    with pytest.raises(pg8000.ProgrammingError):
-        cursor.execute("")
+    """No exception raised"""
+    cursor.execute("")
 
 
 # rolling back when not in a transaction doesn't generate a warning
